[jbossws-commits] JBossWS SVN: r1638 - trunk/src/main/java/javax/xml/soap

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Wed Dec 13 08:37:00 EST 2006


Author: thomas.diesler at jboss.com
Date: 2006-12-13 08:36:59 -0500 (Wed, 13 Dec 2006)
New Revision: 1638

Modified:
   trunk/src/main/java/javax/xml/soap/SOAPFault.java
Log:
Add setFaultCode(QName faultCode)

Modified: trunk/src/main/java/javax/xml/soap/SOAPFault.java
===================================================================
--- trunk/src/main/java/javax/xml/soap/SOAPFault.java	2006-12-13 13:13:27 UTC (rev 1637)
+++ trunk/src/main/java/javax/xml/soap/SOAPFault.java	2006-12-13 13:36:59 UTC (rev 1638)
@@ -258,12 +258,20 @@
     *
     * It is preferable to use this method over setFaultCode(String).
     *
     * @param faultCodeQName  a Name object giving the fault code to be set. It must be namespace qualified.
     * @throws SOAPException if there was an error in adding the faultcode element to the underlying XML tree.
     */
-   void setFaultCode(Name faultCodeQName) throws SOAPException;
+   void setFaultCode(Name faultCode) throws SOAPException;
 
    /**
+    * Sets this SOAPFault object with the given fault code. It is preferable to use this method over setFaultCode(Name).
+    * @param faultCode a QName object giving the fault code to be set. It must be namespace qualified.
+    * @throws SOAPException if there was an error in adding the faultcode element to the underlying XML tree.
+    * @since SAAJ 1.3
+    */
+   void setFaultCode(QName faultCode) throws SOAPException;
+
+   /**
     * Sets the fault string for this SOAPFault object to the given string.
     *
     * @param faultString  a String giving an explanation of the fault
@@ -258,12 +258,20 @@
     * It is preferable to use this method over setFaultCode(String).
     *
-    * @param faultCodeQName  a Name object giving the fault code to be set. It must be namespace qualified.
+    * @param faultCode  a Name object giving the fault code to be set. It must be namespace qualified.
     * @throws SOAPException if there was an error in adding the faultcode element to the underlying XML tree.
     */




More information about the jbossws-commits mailing list